/**
 * This file contains part of the source for MGameServer.
 * Copyright (C) 2006 Kristo Tammeoja
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 * 
 * See the GNU General Public License for more details.
 */
package mgameserver.games.amazons;

import java.awt.*;

import mgameserver.games.*;
import mgameserver.gui.*;

/**
 * Component for drawing clobber board state.
 * @author Kristo Tammeoja
 */
public class AmazonsBoard extends Board {
	
	final Color DARK_SQUARE = new Color(209, 139, 71); 
	final Color LIGHT_SQUARE = new Color(255, 206, 158); 
	
	final Stroke ARROW_STROKE = new BasicStroke((float)3.0, BasicStroke.CAP_ROUND, BasicStroke.JOIN_ROUND);

    private static final long serialVersionUID = -8949073140227817999L;

    /**
     * Creates new instance of ClobberBoard for specified game. 
     */
    public AmazonsBoard(Game game) {
        super(game);
    }

    /* (non-Javadoc)
     * @see mgameserver.gui.Board#drawBoard()
     */
    public void drawBoard(){
        if (this.getGraphics() != null)
            this.drawBoard(this.getGraphics());
    }

    protected void drawBoard(Graphics g){
    	Graphics2D g2 = (Graphics2D)g;
    	// TODO
        if (this.getGame() == null)
            return;
        
        int sqrW = this.getWidth() / this.getGame().getColCount() - 1;
        int sqrH = this.getHeight() / this.getGame().getRowCount() - 1;
        int sqrS = Math.min(sqrW, sqrH);
        
        sqrW = sqrS;
        sqrH = sqrS;

        int boardX = 0;
        int boardY = this.getGame().getRowCount() * sqrS;
        
        // background
        g2.setColor(new Color(128, 64, 0));
        g2.fillRect(0, 0, this.getWidth() - 1, this.getHeight() - 1);
        
        // board
        for (int col = this.getGame().getColCount()-1; col >= 0; col--)
        	for (int row = this.getGame().getRowCount()-1; row >= 0; row--) {
        		if ((col+row)%2 == 0) g2.setColor(DARK_SQUARE);
        		else g2.setColor(LIGHT_SQUARE);
        		g2.fillRect(boardX + col * sqrS, boardY - (row + 1) * sqrS, sqrS, sqrS);
        	}
        
        g2.setColor(Color.GRAY);
        AmazonsMove move = (AmazonsMove)this.getGame().getLastMove();
        if (move != null) {
            g2.fillRect((move.getFromCol() - 1) * sqrW, 
                    (this.getGame().getRowCount() - move.getFromRow()) * sqrH, sqrW, sqrH);
            g2.fillRect((move.getToCol() - 1) * sqrW, 
                    (this.getGame().getRowCount() - move.getToRow()) * sqrH, sqrW, sqrH);
            g2.fillRect((move.getArrowCol() - 1) * sqrW, 
                    (this.getGame().getRowCount() - move.getArrowRow()) * sqrH, sqrW, sqrH);
        }
        
        g2.setColor(Color.BLACK);
        for (int i = this.getGame().getColCount(); i >= 0; i--)
            g2.drawLine(i * sqrW, 0, i * sqrW, this.getGame().getRowCount() * sqrH);
        for (int i = this.getGame().getColCount(); i >= 0; i--)
            g2.drawLine(0, i * sqrH, this.getGame().getColCount() * sqrW, i * sqrH);
        
        for (int col = this.getGame().getColCount() - 1; col >= 0; col--)
            for (int row = this.getGame().getRowCount() - 1; row >= 0; row--) {
                if (getGame().getSqr(col + 1, this.getGame().getRowCount() - row) != Game.EMPTY){
                	int sqr = getGame().getSqr(col + 1, this.getGame().getRowCount() - row);
                	if (sqr == Game.BLACK) g2.setColor(Color.BLACK);
                	else if (sqr == Game.WHITE) g2.setColor(Color.WHITE);
                	else continue;//g2.setColor(Color.BLUE);
                    g2.fillOval(col * sqrW + 1, row * sqrH + 1, sqrW - 2, sqrH - 2);
                }
            }

        for (int col = this.getGame().getColCount(); col >= 1; col--)
            for (int row = this.getGame().getRowCount(); row >= 1; row--) {
            	int sqrX = boardX + (col-1) * sqrS;
            	int sqrY = boardY - row * sqrS;
            	switch (this.getGame().getSqr(col, row)) {
            		case AmazonsGame.ARROW:
            			this.drawArrow(g2, sqrX, sqrY, sqrS); break;
            	}
            }
    }
    
    private void drawArrow(Graphics2D g2, int sqrX, int sqrY, int sqrS) {
    	int space = sqrS / 3;
    	Stroke old_stroke = g2.getStroke();
    	g2.setStroke(ARROW_STROKE);
    	g2.setColor(Color.BLACK);
    	g2.drawLine(sqrX + space, sqrY + space, sqrX + sqrS - space, sqrY + sqrS - space);
    	g2.drawLine(sqrX + space, sqrY + sqrS - space, sqrX + sqrS - space, sqrY + space);
    	g2.setStroke(old_stroke);
    }
}