/**
 * This file contains part of the source for MGameServer.
 * Copyright (C) 2006 Kristo Tammeoja
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 * 
 * See the GNU General Public License for more details.
 */
package mgameserver.games.amazons;

import java.io.*;
import java.net.*;
import java.util.*;

import mgameserver.games.*;
import mgameserver.net.*;
import mgameserver.util.*;

/**
 * Class for communicating a player using protocol for clobber.
 * @author Kristo Tammeoja
 */
public class AmazonsClient extends Client {

    /** 
     * Creates new instance of Amazons client with specified socket.
     * @throws IOException
     * @throws Exception
     */
    public AmazonsClient(Socket socket) throws IOException, Exception {
        super(socket);
    }

    /* (non-Javadoc)
     * @see mgameserver.net.Game#recvMove()
     */
    public Move recvMove() {
        try {
        	StringTokenizer st = new StringTokenizer(this.recvLine());
            int fromCol = Integer.parseInt(st.nextToken()) + 1;
            int fromRow = Integer.parseInt(st.nextToken()) + 1;
            int toCol = Integer.parseInt(st.nextToken()) + 1;
            int toRow = Integer.parseInt(st.nextToken()) + 1;
            int arrowCol = Integer.parseInt(st.nextToken()) + 1;
            int arrowRow = Integer.parseInt(st.nextToken()) + 1;
            return new AmazonsMove(fromCol, fromRow, toCol, toRow, arrowCol, arrowRow);
        } catch(Exception ex) {
            ExceptionHandler.handleException("", ex);
            return null;
        }
    }
    
    /* (non-Javadoc)
     * @see mgameserver.net.Game#sendMove(mgameserver.game.Move)
     */
    public void sendMove(final Move move) {
    	AmazonsMove m = (AmazonsMove)move;
        this.sendMove(m.getFromCol() - 1, m.getFromRow() - 1,
        		      m.getToCol() - 1, m.getToRow() - 1,
        		      m.getArrowCol() - 1, m.getArrowRow() - 1);
    }
    
    private void sendMove(int fromCol, int fromRow, int toCol, int toRow, int arrowCol, int arrowRow) {
        this.sendString(fromCol + " " + fromRow + " " + 
                        toCol + " " + toRow + " " + 
                        arrowCol + " " + arrowRow);
    }
    
    public void sendGameStart(int cols, int rows, boolean starts) {
    	if (starts)
            this.sendString("start");
    }

    public void sendErrorEnd() {
        this.sendString("end");
    }
    
    public void sendError() {
        this.sendString("error");
    }
}
