/**
 * This file contains part of the source for MGameServer.
 * Copyright (C) 2005 Avo Muromgi
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 * 
 * See the GNU General Public License for more details.
 */
package mgameserver.games.clobber;

import java.awt.*;

import mgameserver.games.*;
import mgameserver.gui.*;

/**
 * Component for drawing clobber board state.
 * @author Avo Muromgi
 */
public class ClobberBoard extends Board {

    private static final long serialVersionUID = -8949073140227817199L;

    /**
     * Creates new instance of ClobberBoard for specified game. 
     */
    public ClobberBoard(Game game) {
        super(game);
    }

    /* (non-Javadoc)
     * @see mgameserver.gui.Board#drawBoard()
     */
    public void drawBoard(){
        if (this.getGraphics() != null)
            this.drawBoard(this.getGraphics());
    }

    protected void drawBoard(Graphics g){
        if (this.getGame() == null)
            return;
        int sqrW = this.getWidth() / this.getGame().getColCount() - 1;
        int sqrH = this.getHeight() / this.getGame().getRowCount() - 1;
        g.setColor(new Color(128, 64, 0));
        g.fillRect(0, 0, this.getWidth() - 1, this.getHeight() - 1);
        
        g.setColor(Color.GRAY);
        ClobberMove move = (ClobberMove)this.getGame().getLastMove();
        if (move != null) {
            g.fillRect((move.getFromCol() - 1) * sqrW, 
                    (this.getGame().getRowCount() - move.getFromRow()) * sqrH, sqrW, sqrH);
            g.fillRect((move.getToCol() - 1) * sqrW, 
                    (this.getGame().getRowCount() - move.getToRow()) * sqrH, sqrW, sqrH);
        }
        
        g.setColor(Color.BLACK);
        for (int i = this.getGame().getColCount(); i >= 0; i--)
            g.drawLine(i * sqrW, 0, i * sqrW, this.getGame().getRowCount() * sqrH);
        for (int i = this.getGame().getColCount(); i >= 0; i--)
            g.drawLine(0, i * sqrH, this.getGame().getColCount() * sqrW, i * sqrH);
        
        for (int i = this.getGame().getColCount() - 1; i >= 0; i--)
            for (int j = this.getGame().getRowCount() - 1; j >= 0; j--)
                if (getGame().getSqr(i + 1, this.getGame().getRowCount() - j) != Game.EMPTY){
                    g.setColor(getGame().getSqr(i + 1, this.getGame().getRowCount() - j) 
                            == Game.BLACK ? Color.BLACK : Color.WHITE);
                    g.fillOval(i * sqrW + 1, j * sqrH + 1, sqrW - 2, sqrH - 2);
                }
    }
}