/**
 * This file contains part of the source for MGameServer.
 * Copyright (C) 2005 Avo Muromgi
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 * 
 * See the GNU General Public License for more details.
 */
package mgameserver.games.clobber;

import java.io.*;
import java.net.*;
import java.util.*;

import mgameserver.games.*;
import mgameserver.net.*;
import mgameserver.util.*;

/**
 * Class for communicating a player using protocol for clobber.
 * @author Avo Muromgi
 */
public class ClobberClient extends Client {

    /** 
     * Creates new instance of Clobber client with specified socket.
     * @throws IOException
     * @throws Exception
     */
    public ClobberClient(Socket socket) throws IOException, Exception {
        super(socket);
    }

    /* (non-Javadoc)
     * @see mgameserver.net.Game#recvMove()
     */
    public Move recvMove() {
        try {
            StringTokenizer st = new StringTokenizer(this.recvLine());
            int fromCol = st.nextToken().charAt(0) - 'a' + 1;
            int fromRow = Integer.parseInt(st.nextToken());
            int toCol = st.nextToken().charAt(0) - 'a' + 1;
            int toRow = Integer.parseInt(st.nextToken());
            return new ClobberMove(fromCol, fromRow, toCol, toRow);
        } catch(Exception ex) {
            ExceptionHandler.handleException("", ex);
            return null;
        }
    }
    
    /* (non-Javadoc)
     * @see mgameserver.net.Game#sendMove(mgameserver.game.Move)
     */
    public void sendMove(final Move move) {
        ClobberMove m = (ClobberMove)move;
        this.sendMove(m.getFromCol(), m.getFromRow(), m.getToCol(), m.getToRow());
    }
    
    private void sendMove(final int fromCol, final int fromRow, final int toCol, final int toRow) {
        this.sendString((char)('a' + fromCol - 1) + " " + fromRow + " " 
                + (char)('a' + toCol - 1) + " " + toRow);
    }
    
    public void sendGameStart(int cols, int rows, boolean starts) {
        this.sendString(cols + " " + rows + " " + (starts ? 1 : 0));
    }
}