/**
 * This file contains part of the source for MGameServer.
 * Copyright (C) 2005 Avo Muromgi
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 * 
 * See the GNU General Public License for more details.
 */
package mgameserver.games.corner;

import java.io.IOException;
import java.net.Socket;
import java.util.StringTokenizer;

import mgameserver.Program;
import mgameserver.games.Move;
import mgameserver.net.Client;
import mgameserver.util.ExceptionHandler;

/**
 * Class for communicating a player using protocol for from corner to corner.
 * @author Avo Muromgi
 */
public class CornerClient extends Client {

    /**
     * Creates new instance of Corner client with specified socket.
     * @throws IOException
     * @throws Exception
     */
    public CornerClient(Socket socket) throws IOException, Exception {
        super(socket);
    }

    /* (non-Javadoc)
     * @see mgameserver.net.Game#recvMove()
     */
    public Move recvMove() {
        try {
            StringTokenizer st = new StringTokenizer(this.recvLine());
            int fromCol = Integer.parseInt(st.nextToken());
            int fromRow = Integer.parseInt(st.nextToken());
            int toCol = Integer.parseInt(st.nextToken());
            int toRow = Integer.parseInt(st.nextToken());
            return new CornerMove(fromCol, fromRow, toCol, toRow);
        } catch(Exception ex) {
            ExceptionHandler.handleException("", ex);
            return null;
        }
    }
    
    /* (non-Javadoc)
     * @see mgameserver.net.Game#sendMove(mgameserver.game.Move)
     */
    public void sendMove(final Move move) {
        CornerMove m = (CornerMove) move;
        this.sendMove(m.getFromCol(), m.getFromRow(), m.getToCol(), m.getToRow());
    }
    
    private void sendMove(final int fromCol, final int fromRow, final int toCol, final int toRow) {
        this.sendString(fromCol + " " + fromRow + " " + toCol + " " + toRow);
    }
    
    public void sendGameStart(int cols, int rows, boolean starts) {
        int piecesPerCol = Program.config.getInt("corner.PiecesPerCol");
        int piecesPerRow = Program.config.getInt("corner.PiecesPerRow");
        
        this.sendString(cols + " " + rows + " " + piecesPerCol + " " + piecesPerRow + " " + 
                (starts ? "start" : ""));
    }


    public void sendErrorEnd() {
        this.sendString("end");
    }
    
    public void sendError() {
        this.sendString("error");
    }

}
