/**
 * This file contains part of the source for MGameServer.
 * Copyright (C) 2005 Avo Muromgi
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 * 
 * See the GNU General Public License for more details.
 */
package mgameserver.games.stopgate;

import java.awt.Color;
import java.awt.Graphics;

import mgameserver.games.*;
import mgameserver.gui.*;

/**
 * Board class for Stop-Gate.
 * @author Avo Muromgi
 */
public class StopGateBoard extends Board {

    private static final long serialVersionUID = -3421009180044713501L;

    /**
     * Creates a new instace of the StopGateBoard for specified game.
     * @param game
     */
    public StopGateBoard(Game game) {
        super(game);
    }

    public void drawBoard() {
        if (this.getGraphics() != null)
            this.drawBoard(this.getGraphics());
    }

    protected void drawBoard(Graphics g){
        StopGateGame game = (StopGateGame) this.getGame();
        if (game == null)
            return;
        
        int sqrW = this.getWidth() / game.getColCount() - 1;
        int sqrH = this.getHeight() / game.getRowCount() - 1;
        int dW = (this.getWidth() - game.getColCount() * sqrW) / 2;
        int dH = (this.getHeight() - game.getRowCount() * sqrH) / 2;
        
        g.setColor(new Color(128, 64, 0));
        g.fillRect(0, 0, this.getWidth() - 1, this.getHeight() - 1);

        g.setColor(Color.GRAY);
        StopGateMove move = (StopGateMove)this.getGame().getLastMove();
        if (move != null) {
            g.fillRect(dW + move.getCol() * sqrW,
                    dH + (this.getGame().getRowCount() - move.getRow() - 1) * sqrH, sqrW, sqrH);
            
            if (game.getSqrDir(move.getCol(), move.getRow()) == StopGateGame.BOTTOM)
                g.fillRect(dW + move.getCol() * sqrW,
                        dH + (this.getGame().getRowCount() - move.getRow() - 2) * sqrH, sqrW, sqrH);
            else
                g.fillRect(dW + (move.getCol() + 1) * sqrW,
                        dH + (this.getGame().getRowCount() - move.getRow() - 1) * sqrH, sqrW, sqrH);
        }

        g.setColor(Color.BLACK);
        for (int i = game.getColCount(); i >= 0; i--)
            g.drawLine(dW + i * sqrW, dH, dW + i * sqrW, dH + this.getGame().getRowCount() * sqrH);
        for (int i = game.getColCount(); i >= 0; i--)
            g.drawLine(dW, dH + i * sqrH, dW + this.getGame().getColCount() * sqrW, dH + i * sqrH);
        
        for  (int col = game.getColCount() - 1; col >= 0; col--)
            for (int row = game.getRowCount() - 1; row >= 0; row--)
                if (game.getSqr(col, row) == Game.BLACK 
                        && game.getSqrDir(col, row) == StopGateGame.BOTTOM) {
                    g.setColor(Color.BLACK);
                    int x = dW + col * sqrW + sqrW / 10 + 2;
                    int y = dH + (game.getRowCount() - row - 2) * sqrH + sqrH / 10 + 2;
                    g.fillRect(x, y, 4 * sqrW / 5 - 2, 9 * sqrH / 5 - 2);
                } else if (game.getSqr(col, row) == Game.WHITE 
                        && game.getSqrDir(col, row) == StopGateGame.LEFT) {
                    g.setColor(Color.WHITE);
                    int x = dW + col * sqrW + sqrW / 10 + 2;
                    int y = dH + (game.getRowCount() - row - 1) * sqrH + sqrH / 10 + 2;
                    g.fillRect(x, y, 9 * sqrW / 5 - 2, 4 * sqrH / 5 - 2);
                }
    }
}