/**
 * This file contains part of the source for MGameServer.
 * Copyright (C) 2005 Avo Muromgi
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 * 
 * See the GNU General Public License for more details.
 */
package mgameserver.games.stopgate;

import java.io.*;
import java.net.*;
import java.util.*;

import mgameserver.games.*;
import mgameserver.net.*;
import mgameserver.util.*;

/**
 * Client class for Stop-Gate protocol.
 * @author Avo Muromgi
 */
public class StopGateClient extends Client {

    /**
     * Creates new instance of StopGateClient with specified socket.
     * @throws IOException
     * @throws Exception
     */
    public StopGateClient(Socket socket) throws IOException, Exception {
        super(socket);
    }

    public void sendGameStart(int cols, int rows, boolean starts){
        if (starts)
            this.sendString("start");
    }
    
    public void sendErrorEnd() {
        this.sendString("end");
    }
    
    public void sendError() {
        this.sendString("error");
    }
    
    public Move recvMove() {
        try {
            StringTokenizer st = new StringTokenizer(this.recvLine());
            int col = Integer.parseInt(st.nextToken());
            int row = Integer.parseInt(st.nextToken());
            return new StopGateMove(col, row);
        } catch(Exception ex) {
            ExceptionHandler.handleException("", ex);
            return null;
        }
    }

    /* (non-Javadoc)
     * @see mgameserver.net.Client#sendMove(mgameserver.games.Move)
     */
    public void sendMove(Move move) {
        StopGateMove m = (StopGateMove)move;
        this.sendString(m.getCol() + " " + m.getRow());
    }
}