/**
 * This file contains part of the source for MGameServer.
 * Copyright (C) 2005 Avo Muromgi
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 * 
 * See the GNU General Public License for more details.
 */
package mgameserver.gui;

import java.awt.*;

import javax.swing.*;

import mgameserver.games.*;

/**
 * Abstract base class for drawing game state to form. 
 * @author Avo Muromgi
 */
public abstract class Board extends JPanel {

    private static final long serialVersionUID = -3635543197502742467L;

    /**
     * Creates new instance of Board with specified game.
     */
    public Board(Game game) {
        super();
        this.setMinimumSize(new Dimension(100, 100));
        this.game = game;
        this.drawBoard();
    }
    
    /**
     * Gets the game drawn on current board.
     */
    public Game getGame() {
        return this.game;
    }
    private Game game;
    
    /**
     * Draws game state to current board.
     */
    public abstract void drawBoard();

    /**
     * Draws game state to specified graphics context.
     */
    protected abstract void drawBoard(Graphics g);
    
    public void paintComponent(Graphics g){
        super.paintComponent(g);
        this.drawBoard(g);
    }
}