/**
 * This file contains part of the source for MGameServer.
 * Copyright (C) 2005 Avo Muromgi
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 * 
 * See the GNU General Public License for more details.
 */
package mgameserver.gui;

import java.awt.*;
import java.awt.event.*;

import javax.swing.*;

import mgameserver.*;
import mgameserver.games.*;
import mgameserver.net.*;

/**
 * MainForm for the application.
 * @author Avo Muromgi
 */
public class MainForm extends JFrame implements ActionListener {

    /**
     * Gets the singleton instance of the MainForm.
     */
    public static MainForm getInstance() {
        if (instance == null)
            instance = new MainForm();
        return instance;
    }
	private static MainForm instance;
    
	private static final long serialVersionUID = -2685760790902340031L;

    /**
     * Sets names of the players on the form.
     * @param player1
     * @param player2
     */
    public void setPlayerNames(String player1, String player2) {
        this.txtPlayer1.setText(player1 == null ? "" : player1);
        this.txtPlayer2.setText(player2 == null ? "" : player2);
        this.btnStartGame.setEnabled(player1 != null && player2 != null);
    }
    
    /**
     * Updates clients scores on the form.
     */
    public void updateScores() {
        int gamesWon1 = Integer.parseInt(this.txtGamesWon1.getText());
        int gamesWon2 = Integer.parseInt(this.txtGamesWon2.getText());
        Font font = this.txtGamesWon1.getFont();
        
        if (gamesWon1 != this.server.getClient(0).getGamesWon()){
            this.txtGamesWon1.setText(Integer.toString(this.server.getClient(0).getGamesWon()));
            this.txtPlayer1.setFont(new Font(font.getName(), Font.BOLD, font.getSize()));
            this.txtGamesWon1.setFont(new Font(font.getName(), Font.BOLD, font.getSize()));
        } else {
            this.txtPlayer1.setFont(new Font(font.getName(), Font.PLAIN, font.getSize()));
            this.txtGamesWon1.setFont(new Font(font.getName(), Font.PLAIN, font.getSize()));
        }
        
        if (gamesWon2 != this.server.getClient(1).getGamesWon()){
            this.txtGamesWon2.setText(Integer.toString(this.server.getClient(1).getGamesWon()));
            this.txtPlayer2.setFont(new Font(font.getName(), Font.BOLD, font.getSize()));
            this.txtGamesWon2.setFont(new Font(font.getName(), Font.BOLD, font.getSize()));
        } else {
            this.txtPlayer2.setFont(new Font(font.getName(), Font.PLAIN, font.getSize()));
            this.txtGamesWon2.setFont(new Font(font.getName(), Font.PLAIN, font.getSize()));
        }

        this.pnlColor1.repaint();
        this.pnlColor2.repaint();
    }

    /**
     * Gets the board panel of the current main form.
     */
    public Board getBoardPanel() {
        return this.pnlBoard;
    }
    
	/**
     * Creates new instance of MainForm.
	 * @throws HeadlessException
	 */
	protected MainForm() throws HeadlessException {
		super("MGameServer");
		this.initControls();
	}
	
    /**
     * Creates all the components on the form.
     */
	protected void initControls() {
        this.setSize(400, 460);
//
        this.getContentPane().setLayout(new BorderLayout());
        this.setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);
        
        this.pnlBoard = Program.getNewGameBoard();
//
        this.getContentPane().add(this.pnlBoard, BorderLayout.CENTER);
        
        this.pnlButtons = new JPanel();
//
        this.getContentPane().add(this.pnlButtons, BorderLayout.SOUTH);
        
		this.btnStartServer = new JButton("Start Server");
		this.pnlButtons.add(this.btnStartServer);
        this.btnStartServer.addActionListener(this);
        
        this.btnStartGame = new JButton("Start Game");
        this.pnlButtons.add(this.btnStartGame);
        this.btnStartGame.addActionListener(this);
        this.btnStartGame.setEnabled(false);
        
        this.pnlStatus = new JPanel();
        this.getContentPane().add(this.pnlStatus, BorderLayout.NORTH);
        this.pnlStatus.setLayout(null);
        this.pnlStatus.setPreferredSize(new Dimension(this.getWidth(), 40));
        
        this.lblPlayer1 = new JLabel("Player 1: ");
        this.pnlStatus.add(this.lblPlayer1);
        this.lblPlayer1.setLocation(8, 0);
        this.lblPlayer1.setSize(60, 20);
        
        this.pnlColor1 = new JPanel() {
            public void paint(Graphics g) {
                super.paint(g);
                if (judge != null) { 
                    g.setColor(judge.getPlayer1Color());
                    g.fillRect(0, 0, pnlColor1.getWidth(), pnlColor1.getHeight());
                }
            }
            private static final long serialVersionUID = -6397696341442050929L;
        };
        this.pnlColor1.setLocation(
                this.lblPlayer1.getX() + this.lblPlayer1.getWidth(), this.lblPlayer1.getY());
        this.pnlColor1.setSize(20, 20);
        this.pnlStatus.add(this.pnlColor1);
        
        this.txtPlayer1 = new JTextField();
        this.pnlStatus.add(this.txtPlayer1);
        this.txtPlayer1.setEditable(false);
        this.txtPlayer1.setLocation(
                this.pnlColor1.getX() + this.pnlColor1.getWidth(), this.pnlColor1.getY());
        this.txtPlayer1.setSize(100, 20);
        
        this.lblGamesWon1 = new JLabel("Games Won: ");
        this.pnlStatus.add(this.lblGamesWon1);
        this.lblGamesWon1.setLocation(
                this.txtPlayer1.getX() + this.txtPlayer1.getWidth() + 8, this.txtPlayer1.getY());
        this.lblGamesWon1.setSize(80, 20);
        
        this.txtGamesWon1 = new JTextField();
        this.pnlStatus.add(this.txtGamesWon1);
        this.txtGamesWon1.setEditable(false);
        this.txtGamesWon1.setLocation(
                this.lblGamesWon1.getX() + this.lblGamesWon1.getWidth(), this.lblGamesWon1.getY());
        this.txtGamesWon1.setSize(100, 20);
        
        this.lblPlayer2 = new JLabel("Player 2: ");
        this.pnlStatus.add(this.lblPlayer2);
        this.lblPlayer2.setLocation(8, 20);
        this.lblPlayer2.setSize(60, 20);
        
        this.pnlColor2 = new JPanel() {
            public void paint(Graphics g) {
                super.paint(g);
                if (judge != null) { 
                    g.setColor(judge.getPlayer2Color());
                    g.fillRect(0, 0, pnlColor2.getWidth(), pnlColor2.getHeight());
                }
            }
            private static final long serialVersionUID = 5800354679290442220L;
        };
        this.pnlColor2.setLocation(
                this.lblPlayer2.getX() + this.lblPlayer2.getWidth(), this.lblPlayer2.getY());
        this.pnlColor2.setSize(20, 20);
        this.pnlStatus.add(this.pnlColor2);
        
        this.txtPlayer2 = new JTextField();
        this.pnlStatus.add(this.txtPlayer2);
        this.txtPlayer2.setEditable(false);
        this.txtPlayer2.setLocation(
                this.pnlColor2.getX() + this.pnlColor2.getWidth(), this.pnlColor2.getY());
        this.txtPlayer2.setSize(100, 20);
        
        this.lblGamesWon2 = new JLabel("Games Won: ");
        this.pnlStatus.add(this.lblGamesWon2);
        this.lblGamesWon2.setLocation(
                this.txtPlayer2.getX() + this.txtPlayer2.getWidth() + 8, this.txtPlayer2.getY());
        this.lblGamesWon2.setSize(80, 20);
        
        this.txtGamesWon2 = new JTextField();
        this.pnlStatus.add(this.txtGamesWon2);
        this.txtGamesWon2.setEditable(false);
        this.txtGamesWon2.setLocation(
                this.lblGamesWon2.getX() + this.lblGamesWon2.getWidth(), this.lblGamesWon2.getY());
        this.txtGamesWon2.setSize(100, 20);
	}

    // Event handling
    public void actionPerformed(ActionEvent e) {
        if (this.btnStartServer.equals(e.getSource()))
            this.startServer();
        else if (this.btnStartGame.equals(e.getSource()))
            this.startGame();
    }
    // end of event handling
    
    private void startServer() {
        this.server = 
            new Server(Program.config.getString("BindIP"), Program.config.getInt("BindPort"));
        this.server.start();
        this.btnStartServer.setEnabled(false);
    }
    private Server server;
    
    private void startGame() {
        this.txtGamesWon1.setText("0");
        this.txtGamesWon2.setText("0");
        this.judge = 
            new Judge(this.server.getClient(0), this.server.getClient(1), this.pnlBoard.getGame());
        this.judge.start();
        this.btnStartGame.setEnabled(false);
    }
    private Judge judge;
    
	// Controls
	private Board pnlBoard;
    private JPanel pnlButtons;
	private JButton btnStartServer;
    private JButton btnStartGame;
    
    private JPanel pnlStatus;
    private JLabel lblPlayer1;
    private JPanel pnlColor1;
    private JTextField txtPlayer1;
    private JLabel lblGamesWon1;
    private JTextField txtGamesWon1;
    private JLabel lblPlayer2;
    private JPanel pnlColor2;
    private JTextField txtPlayer2;
    private JLabel lblGamesWon2;
    private JTextField txtGamesWon2;
}
