/**
 * This file contains part of the source for MGameServer.
 * Copyright (C) 2005 Avo Muromgi
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 * 
 * See the GNU General Public License for more details.
 */
package mgameserver.gui;

import java.awt.*;
import java.awt.event.*;

import javax.swing.*;

/**
 * @author Avo Muromgi
 */
public class NewGameDlg extends Dialog implements ActionListener {

    /**
     * Result of the dialog, if user indicated that no special action should be taken.
     */
    public static final int NONE = 0;

    /**
     * Result of the dialog, if user indicated that playing games should be stopped.
     */
    public static final int STOP = 1;

    /**
     * Result of the dialog, if user indicated that playing games should be continued.
     */
    public static final int CONTINUE = 2;

    /**
     * Result of the dialog, if user indicated that players colors should be switched and a new game 
     * should be started.
     */
    public static final int SWITCH_COLORS = 3;
    
    /**
     * Displayes a modal new game dialog for given parent.
     * @return Result of the dialog.
     */
    public static int showNewGameDlg(Frame parent) {
        if (instance == null)
            instance = new NewGameDlg(parent);
        instance.setVisible(true);
        return instance.getResult();
    }
    private static NewGameDlg instance;
    
    private static final long serialVersionUID = -1895893932866363030L;

    /**
     * Creates a new instance of NewGameDlg for given parent.
     */
    private NewGameDlg(Frame parent) {
        super(parent, true);
        this.initControls();
    }

    /**
     * Gets the result of the dialog. Default is <code>NONE</code>.
     */
    public int getResult(){
        return this.result;
    }
    private int result = NONE;

    // Event handling
    public void actionPerformed(ActionEvent e) {
        if (this.btnSwitch == e.getSource())
            this.result = SWITCH_COLORS;
        else if (this.btnReplay == e.getSource())
            this.result = CONTINUE;
        else if (this.btnStop == e.getSource())
            this.result = STOP;
        this.setVisible(false);
    }
    // End of event handling
    
    /**
     * Creates all the components on the dialog.
     */
    protected void initControls(){
        this.setLayout(new BorderLayout());
        this.lblQuestion = new JLabel(
                "Switch colors and continue, replay or shut down the server?");
        this.add(this.lblQuestion, BorderLayout.CENTER);
        
        this.pnlButtons = new JPanel();
        this.add(this.pnlButtons, BorderLayout.SOUTH);
        this.btnSwitch = new JButton("Switch colors");
        this.pnlButtons.add(this.btnSwitch);
        this.btnSwitch.addActionListener(this);
        this.btnReplay = new JButton("Replay");
        this.pnlButtons.add(this.btnReplay);
        this.btnReplay.addActionListener(this);
        this.btnStop = new JButton("Stop server");
        this.pnlButtons.add(this.btnStop);
        this.btnStop.addActionListener(this);
        this.pack();
    }
    
    // Controls
    private JLabel lblQuestion;
    private JPanel pnlButtons;
    private JButton btnSwitch;
    private JButton btnReplay;
    private JButton btnStop;
}
