/**
 * This file contains part of the source for MGameServer.
 * Copyright (C) 2005 Avo Muromgi
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 * 
 * See the GNU General Public License for more details.
 */
package mgameserver.net;

import java.io.*;
import java.net.*;
import java.util.*;

import mgameserver.*;
import mgameserver.gui.*;
import mgameserver.util.*;

/**
 * Server thread class for accepting clients.
 * @author Avo Muromgi
 */
public class Server extends Thread {

    /**
     * Creates new instance of Server and binds it to specified ip and port.
     */
	public Server(final String ip, final int port) {
		super();
		this.ip = ip;
		this.port = port;
        this.clients = new ArrayList();
	}

	public void run() {
        Program.logger.log(this, "Server started");
        try {
            this.bindSocket();
            while(this.clients.size() < 2) {
                Client client = Program.getNewClient(this.server.accept());
                if (!client.isAccepted()) {
                    Program.logger.log(this, "Invalid connection attempt: unknown client.");
                    continue;
                }
                this.clients.add(client);
                synchronized(MainForm.getInstance()) {
                    MainForm.getInstance().setPlayerNames(
                            this.clients.size() < 1 ? 
                                    null : ((Client)this.clients.get(0)).getName(),
                            this.clients.size() < 2 ? 
                                    null : ((Client)this.clients.get(1)).getName());
                }
            }
        } catch (IOException ex) {
            ExceptionHandler.handleException("", ex);
        } catch (Exception ex) {
            ExceptionHandler.handleException("", ex);
        }
	}
	
    /**
     * Gets the client by the index.
     */
    public Client getClient(final int index) {
        return index < 0 || index >= this.clients.size() ? null : (Client)this.clients.get(index); 
    }
    private List clients;
    
	private void bindSocket() throws IOException {
        this.server = new ServerSocket();
        // find address
        InetSocketAddress address;
        if (null == this.ip || this.ip.isEmpty()) address = new InetSocketAddress(this.port);
        else address = new InetSocketAddress(this.ip, this.port);
        // bind
        this.server.bind(address);
	}
	
	private String ip;
	private int port;
	private ServerSocket server;
}
