/**
 * This file contains part of the source for MGameServer.
 * Copyright (C) 2005 Avo Muromgi
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
 * 
 * See the GNU General Public License for more details.
 */
package mgameserver.util;

import java.io.*;
import java.util.*;

/**
 * Class for managing resources.
 * @author Avo Muromgi
 */
public class Resources {

    /**
     * Creates new instance of resources. 
     * @throws IOException 
     * @throws FileNotFoundException 
     */
    public Resources(String file) throws FileNotFoundException, IOException {
        super();
        this.file = file;
        this.load();
    }

    /**
     * Loads resources.
     * @throws FileNotFoundException
     * @throws IOException
     */
    protected void load() throws FileNotFoundException, IOException{
        this.resources = new PropertyResourceBundle(new FileInputStream(this.file));
    }
    
    /**
     * Gets an item with a specified key.
     */
    public String getString(String key){
        try{
            return this.resources.getString(key);
        }catch(MissingResourceException ex){
            ExceptionHandler.handleException("Resource not found", ex);
            return MISSING_STRING;
        }
    }

    /**
     * Gets an integer value of an item with a specified key.
     */
    public int getInt(String key){
        String res = this.getString(key);
        try{
            return Integer.parseInt(res);
        }catch(NumberFormatException ex){
            ExceptionHandler.handleException("Resource " + res + " is not an integer.", ex);
            return MISSING_INT;
        }
    }

    /**
     * Gets an boolean value of an item with a specified key. 
     */
    public boolean getBoolean(String key){
        String res = this.getString(key).trim().toUpperCase();
        return res.equals("1") || res.equals("TRUE") || res.equals("T");
    }
    
    /**
     * Checks, whether item with specified key exists.
     */
    public boolean exists(String key) {
        try{
            this.resources.getString(key);
            return true;
        }catch(MissingResourceException ex){
            return false;
        }
    }
    
    private static final String MISSING_STRING = "";
    private static final int MISSING_INT = 0;
    private PropertyResourceBundle resources;
    private String file;
}